Learn R Programming

ezr (version 0.1.5)

desc_stats: Descriptive statistics

Description

Returns descriptive statistics for a numeric vector.

Usage

desc_stats(vector = NULL, notify_na_count = NULL)

Arguments

vector

a numeric vector

notify_na_count

if TRUE, notify how many observations were removed due to missing values. By default, NA count will be printed only if there are any NA values.

Value

a named numeric vector

Examples

Run this code
# NOT RUN {
desc_stats(1:100)
desc_stats(c(1:100, NA))
# }

Run the code above in your browser using DataLab