Learn R Programming

ezr (version 0.1.5)

se_of_mean: Standard error of the mean

Description

Standard error of the mean

Usage

se_of_mean(vector, na.rm = TRUE, notify_na_count = NULL)

Arguments

vector

a numeric vector

na.rm

if TRUE, NA values will be removed before calculation

notify_na_count

if TRUE, notify how many observations were removed due to missing values. By default, NA count will be printed only if there are any NA values.

Examples

Run this code
# NOT RUN {
se_of_mean(c(1:10, NA))
# }

Run the code above in your browser using DataLab