powered by
Returns descriptive statistics for a numeric vector.
desc_stats(vector = NULL, notify_na_count = NULL)
a numeric vector
if TRUE, notify how many observations were removed due to missing values. By default, NA count will be printed only if there are any NA values.
TRUE
a named numeric vector
# NOT RUN { desc_stats(1:100) desc_stats(c(1:100, NA)) # }
Run the code above in your browser using DataLab