powered by
Standard error of the mean
se_of_mean(vector, na.rm = TRUE, notify_na_count = NULL)
a numeric vector
if TRUE, NA values will be removed before calculation
TRUE
if TRUE, notify how many observations were removed due to missing values. By default, NA count will be printed only if there are any NA values.
# NOT RUN { se_of_mean(c(1:10, NA)) # }
Run the code above in your browser using DataLab